@@ -11,7 +11,7 @@
 # under the License.
 
 from openstack.identity import identity_service
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class Region(resource.Resource):
@@ -26,7 +26,11 @@ class Region(resource.Resource):
     allow_update = True
     allow_delete = True
     allow_list = True
-    patch_update = True
+    update_method = 'PATCH'
+
+    _query_mapping = resource.QueryParameters(
+        'parent_region_id',
+    )
 
     # Properties
     #: User-facing description of the region. *Type: string*
