@@ -11,10 +11,11 @@
 # under the License.
 
 from openstack.network import network_service
-from openstack import resource2 as resource
+from openstack.network.v2 import tag
+from openstack import resource
 
 
-class FloatingIP(resource.Resource):
+class FloatingIP(resource.Resource, tag.TagMixin):
     name_attribute = "floating_ip_address"
     resource_name = "floating ip"
     resource_key = 'floatingip'
@@ -30,15 +31,21 @@ class FloatingIP(resource.Resource):
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
-        'description', 'fixed_ip_address', 'floating_ip_address',
-        'floating_network_id', 'port_id', 'router_id', 'status',
-        project_id='tenant_id')
+        'description', 'fixed_ip_address',
+        'floating_ip_address', 'floating_network_id',
+        'port_id', 'router_id', 'status', 'subnet_id',
+        project_id='tenant_id',
+        **tag.TagMixin._tag_query_parameters)
 
     # Properties
     #: Timestamp at which the floating IP was created.
     created_at = resource.Body('created_at')
     #: The floating IP description.
     description = resource.Body('description')
+    #: The DNS domain.
+    dns_domain = resource.Body('dns_domain')
+    #: The DNS name.
+    dns_name = resource.Body('dns_name')
     #: The fixed IP address associated with the floating IP. If you
     #: intend to associate the floating IP with a fixed IP at creation
     #: time, then you must indicate the identifier of the internal port.
@@ -53,8 +60,15 @@ class FloatingIP(resource.Resource):
     name = floating_ip_address
     #: The ID of the network associated with the floating IP.
     floating_network_id = resource.Body('floating_network_id')
+    #: Read-only. The details of the port that this floating IP associates
+    #: with. Present if ``fip-port-details`` extension is loaded.
+    #: *Type: dict with keys: name, network_id, mac_address, admin_state_up,
+    #: status, device_id, device_owner*
+    port_details = resource.Body('port_details', type=dict)
     #: The port ID.
     port_id = resource.Body('port_id')
+    #: The ID of the QoS policy attached to the floating IP.
+    qos_policy_id = resource.Body('qos_policy_id')
     #: The ID of the project this floating IP is associated with.
     project_id = resource.Body('tenant_id')
     #: Revision number of the floating IP. *Type: int*
@@ -65,11 +79,14 @@ class FloatingIP(resource.Resource):
     status = resource.Body('status')
     #: Timestamp at which the floating IP was last updated.
     updated_at = resource.Body('updated_at')
+    #: The Subnet ID associated with the floating IP.
+    subnet_id = resource.Body('subnet_id')
 
     @classmethod
     def find_available(cls, session):
-        info = cls.list(session, fields='id', port_id='')
-        try:
-            return next(info)
-        except StopIteration:
-            return None
+        # server-side filtering on empty values is not always supported.
+        # TODO(mordred) Make this check for support for the server-side filter
+        for ip in cls.list(session):
+            if not ip.port_id:
+                return ip
+        return None
