@@ -415,11 +415,6 @@ class TestObjectUploads(BaseTestObject):
     def test_create_object(self):
 
         self.register_uris([
-            dict(method='GET',
-                 uri='https://object-store.example.com/info',
-                 json=dict(
-                     swift={'max_file_size': 1000},
-                     slo={'min_segment_size': 500})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}'.format(
                      endpoint=self.endpoint,
@@ -447,6 +442,11 @@ class TestObjectUploads(BaseTestObject):
                      'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
                      'X-Container-Bytes-Used': '0',
                      'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='GET',
+                 uri='https://object-store.example.com/info',
+                 json=dict(
+                     swift={'max_file_size': 1000},
+                     slo={'min_segment_size': 500})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}/{object}'.format(
                      endpoint=self.endpoint, container=self.container,
@@ -470,18 +470,58 @@ class TestObjectUploads(BaseTestObject):
 
         self.assert_calls()
 
+    def test_create_directory_marker_object(self):
+
+        self.register_uris([
+            dict(method='HEAD',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint,
+                     container=self.container),
+                 status_code=404),
+            dict(method='PUT',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint, container=self.container),
+                 status_code=201,
+                 headers={
+                     'Date': 'Fri, 16 Dec 2016 18:21:20 GMT',
+                     'Content-Length': '0',
+                     'Content-Type': 'text/html; charset=UTF-8',
+                 }),
+            dict(method='HEAD',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint, container=self.container),
+                 headers={
+                     'Content-Length': '0',
+                     'X-Container-Object-Count': '0',
+                     'Accept-Ranges': 'bytes',
+                     'X-Storage-Policy': 'Policy-0',
+                     'Date': 'Fri, 16 Dec 2016 18:29:05 GMT',
+                     'X-Timestamp': '1481912480.41664',
+                     'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
+                     'X-Container-Bytes-Used': '0',
+                     'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='PUT',
+                 uri='{endpoint}/{container}/{object}'.format(
+                     endpoint=self.endpoint,
+                     container=self.container, object=self.object),
+                 status_code=201,
+                 validate=dict(
+                     headers={
+                         'content-type': 'application/directory',
+                     }))
+        ])
+
+        self.cloud.create_directory_marker_object(
+            container=self.container, name=self.object)
+
+        self.assert_calls()
+
     def test_create_dynamic_large_object(self):
 
         max_file_size = 2
         min_file_size = 1
 
         uris_to_mock = [
-            dict(method='GET',
-                 uri='https://object-store.example.com/info',
-                 json=dict(
-                     swift={'max_file_size': max_file_size},
-                     slo={'min_segment_size': min_file_size})),
-
             dict(method='HEAD',
                  uri='{endpoint}/{container}'.format(
                      endpoint=self.endpoint,
@@ -511,6 +551,11 @@ class TestObjectUploads(BaseTestObject):
                      'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
                      'X-Container-Bytes-Used': '0',
                      'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='GET',
+                 uri='https://object-store.example.com/info',
+                 json=dict(
+                     swift={'max_file_size': max_file_size},
+                     slo={'min_segment_size': min_file_size})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}/{object}'.format(
                      endpoint=self.endpoint, container=self.container,
@@ -562,10 +607,6 @@ class TestObjectUploads(BaseTestObject):
         min_file_size = 1
 
         uris_to_mock = [
-            dict(method='GET', uri='https://object-store.example.com/info',
-                 json=dict(
-                     swift={'max_file_size': max_file_size},
-                     slo={'min_segment_size': min_file_size})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}'.format(
                      endpoint=self.endpoint,
@@ -595,6 +636,10 @@ class TestObjectUploads(BaseTestObject):
                      'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
                      'X-Container-Bytes-Used': '0',
                      'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='GET', uri='https://object-store.example.com/info',
+                 json=dict(
+                     swift={'max_file_size': max_file_size},
+                     slo={'min_segment_size': min_file_size})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}/{object}'.format(
                      endpoint=self.endpoint,
@@ -681,10 +726,6 @@ class TestObjectUploads(BaseTestObject):
         min_file_size = 1
 
         self.register_uris([
-            dict(method='GET', uri='https://object-store.example.com/info',
-                 json=dict(
-                     swift={'max_file_size': max_file_size},
-                     slo={'min_segment_size': min_file_size})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}'.format(
                      endpoint=self.endpoint,
@@ -714,6 +755,10 @@ class TestObjectUploads(BaseTestObject):
                      'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
                      'X-Container-Bytes-Used': '0',
                      'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='GET', uri='https://object-store.example.com/info',
+                 json=dict(
+                     swift={'max_file_size': max_file_size},
+                     slo={'min_segment_size': min_file_size})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}/{object}'.format(
                      endpoint=self.endpoint,
@@ -765,10 +810,6 @@ class TestObjectUploads(BaseTestObject):
         min_file_size = 1
 
         self.register_uris([
-            dict(method='GET', uri='https://object-store.example.com/info',
-                 json=dict(
-                     swift={'max_file_size': max_file_size},
-                     slo={'min_segment_size': min_file_size})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}'.format(
                      endpoint=self.endpoint,
@@ -798,6 +839,10 @@ class TestObjectUploads(BaseTestObject):
                      'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
                      'X-Container-Bytes-Used': '0',
                      'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='GET', uri='https://object-store.example.com/info',
+                 json=dict(
+                     swift={'max_file_size': max_file_size},
+                     slo={'min_segment_size': min_file_size})),
             dict(method='HEAD',
                  uri='{endpoint}/{container}/{object}'.format(
                      endpoint=self.endpoint,
@@ -895,3 +940,105 @@ class TestObjectUploads(BaseTestObject):
                 'etag': 'etag3',
             },
         ], self.adapter.request_history[-1].json())
+
+    def test_create_object_skip_checksum(self):
+
+        self.register_uris([
+            dict(method='HEAD',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint,
+                     container=self.container),
+                 status_code=404),
+            dict(method='PUT',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint, container=self.container),
+                 status_code=201,
+                 headers={
+                     'Date': 'Fri, 16 Dec 2016 18:21:20 GMT',
+                     'Content-Length': '0',
+                     'Content-Type': 'text/html; charset=UTF-8',
+                 }),
+            dict(method='HEAD',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint, container=self.container),
+                 headers={
+                     'Content-Length': '0',
+                     'X-Container-Object-Count': '0',
+                     'Accept-Ranges': 'bytes',
+                     'X-Storage-Policy': 'Policy-0',
+                     'Date': 'Fri, 16 Dec 2016 18:29:05 GMT',
+                     'X-Timestamp': '1481912480.41664',
+                     'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
+                     'X-Container-Bytes-Used': '0',
+                     'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='GET',
+                 uri='https://object-store.example.com/info',
+                 json=dict(
+                     swift={'max_file_size': 1000},
+                     slo={'min_segment_size': 500})),
+            dict(method='HEAD',
+                 uri='{endpoint}/{container}/{object}'.format(
+                     endpoint=self.endpoint, container=self.container,
+                     object=self.object),
+                 status_code=200),
+            dict(method='PUT',
+                 uri='{endpoint}/{container}/{object}'.format(
+                     endpoint=self.endpoint,
+                     container=self.container, object=self.object),
+                 status_code=201,
+                 validate=dict(headers={})),
+        ])
+
+        self.cloud.create_object(
+            container=self.container, name=self.object,
+            filename=self.object_file.name,
+            generate_checksums=False)
+
+        self.assert_calls()
+
+    def test_create_object_data(self):
+
+        self.register_uris([
+            dict(method='HEAD',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint,
+                     container=self.container),
+                 status_code=404),
+            dict(method='PUT',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint, container=self.container),
+                 status_code=201,
+                 headers={
+                     'Date': 'Fri, 16 Dec 2016 18:21:20 GMT',
+                     'Content-Length': '0',
+                     'Content-Type': 'text/html; charset=UTF-8',
+                 }),
+            dict(method='HEAD',
+                 uri='{endpoint}/{container}'.format(
+                     endpoint=self.endpoint, container=self.container),
+                 headers={
+                     'Content-Length': '0',
+                     'X-Container-Object-Count': '0',
+                     'Accept-Ranges': 'bytes',
+                     'X-Storage-Policy': 'Policy-0',
+                     'Date': 'Fri, 16 Dec 2016 18:29:05 GMT',
+                     'X-Timestamp': '1481912480.41664',
+                     'X-Trans-Id': 'tx60ec128d9dbf44b9add68-0058543271dfw1',
+                     'X-Container-Bytes-Used': '0',
+                     'Content-Type': 'text/plain; charset=utf-8'}),
+            dict(method='PUT',
+                 uri='{endpoint}/{container}/{object}'.format(
+                     endpoint=self.endpoint,
+                     container=self.container, object=self.object),
+                 status_code=201,
+                 validate=dict(
+                     headers={},
+                     data=self.content,
+                 )),
+        ])
+
+        self.cloud.create_object(
+            container=self.container, name=self.object,
+            data=self.content)
+
+        self.assert_calls()
