@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 
 from openstack.compute.v2 import availability_zone as az
 
@@ -23,18 +23,24 @@ BASIC_EXAMPLE = {
 }
 
 
-class TestAvailabilityZone(testtools.TestCase):
+class TestAvailabilityZone(base.TestCase):
 
     def test_basic(self):
         sot = az.AvailabilityZone()
-        self.assertEqual('availability_zone', sot.resource_key)
         self.assertEqual('availabilityZoneInfo', sot.resources_key)
         self.assertEqual('/os-availability-zone', sot.base_path)
         self.assertTrue(sot.allow_list)
         self.assertEqual('compute', sot.service.service_type)
 
+    def test_basic_detail(self):
+        sot = az.AvailabilityZoneDetail()
+        self.assertEqual('availabilityZoneInfo', sot.resources_key)
+        self.assertEqual('/os-availability-zone/detail', sot.base_path)
+        self.assertTrue(sot.allow_list)
+        self.assertEqual('compute', sot.service.service_type)
+
     def test_make_basic(self):
-        sot = az.AvailabilityZone(BASIC_EXAMPLE)
+        sot = az.AvailabilityZone(**BASIC_EXAMPLE)
         self.assertEqual(BASIC_EXAMPLE['id'], sot.id)
         self.assertEqual(BASIC_EXAMPLE['zoneState'], sot.state)
         self.assertEqual(BASIC_EXAMPLE['hosts'], sot.hosts)
