@@ -14,6 +14,7 @@ import deprecation
 import mock
 import uuid
 
+from openstack import exceptions
 from openstack.network.v2 import _proxy
 from openstack.network.v2 import address_scope
 from openstack.network.v2 import agent
@@ -48,8 +49,8 @@ from openstack.network.v2 import service_provider
 from openstack.network.v2 import subnet
 from openstack.network.v2 import subnet_pool
 from openstack.network.v2 import vpn_service
-from openstack import proxy2 as proxy_base2
-from openstack.tests.unit import test_proxy_base2
+from openstack import proxy as proxy_base
+from openstack.tests.unit import test_proxy_base
 
 
 QOS_POLICY_ID = 'qos-policy-id-' + uuid.uuid4().hex
@@ -59,7 +60,7 @@ AGENT_ID = 'agent-id-' + uuid.uuid4().hex
 ROUTER_ID = 'router-id-' + uuid.uuid4().hex
 
 
-class TestNetworkProxy(test_proxy_base2.TestProxyBase):
+class TestNetworkProxy(test_proxy_base.TestProxyBase):
     def setUp(self):
         super(TestNetworkProxy, self).setUp()
         self.proxy = _proxy.Proxy(self.session)
@@ -314,6 +315,15 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def test_network_find(self):
         self.verify_find(self.proxy.find_network, network.Network)
 
+    def test_network_find_with_filter(self):
+        self._verify2('openstack.proxy.Proxy._find',
+                      self.proxy.find_network,
+                      method_args=["net1"],
+                      method_kwargs={"project_id": "1"},
+                      expected_args=[network.Network, "net1"],
+                      expected_kwargs={"project_id": "1",
+                                       "ignore_missing": True})
+
     def test_network_get(self):
         self.verify_get(self.proxy.get_network, network.Network)
 
@@ -396,7 +406,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                            {"pool": "test_id"}, {"pool_id": "test_id"})
 
     def test_pool_member_find(self):
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_pool_member,
                       method_args=["MEMBER", "POOL"],
                       expected_args=[pool_member.PoolMember, "MEMBER"],
@@ -404,7 +414,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                                        "ignore_missing": True})
 
     def test_pool_member_get(self):
-        self._verify2('openstack.proxy2.BaseProxy._get',
+        self._verify2('openstack.proxy.Proxy._get',
                       self.proxy.get_pool_member,
                       method_args=["MEMBER", "POOL"],
                       expected_args=[pool_member.PoolMember, "MEMBER"],
@@ -416,7 +426,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                          expected_kwargs={"pool_id": "test_id"})
 
     def test_pool_member_update(self):
-        self._verify2("openstack.proxy2.BaseProxy._update",
+        self._verify2("openstack.proxy.Proxy._update",
                       self.proxy.update_pool_member,
                       method_args=["MEMBER", "POOL"],
                       expected_args=[pool_member.PoolMember, "MEMBER"],
@@ -487,7 +497,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_bandwidth_limit_rule_find(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_qos_bandwidth_limit_rule,
                       method_args=['rule_id', policy],
                       expected_args=[
@@ -513,7 +523,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_bandwidth_limit_rule_update(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._update',
+        self._verify2('openstack.proxy.Proxy._update',
                       self.proxy.update_qos_bandwidth_limit_rule,
                       method_args=['rule_id', policy],
                       method_kwargs={'foo': 'bar'},
@@ -546,7 +556,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_dscp_marking_rule_find(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_qos_dscp_marking_rule,
                       method_args=['rule_id', policy],
                       expected_args=[qos_dscp_marking_rule.QoSDSCPMarkingRule,
@@ -571,7 +581,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_dscp_marking_rule_update(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._update',
+        self._verify2('openstack.proxy.Proxy._update',
                       self.proxy.update_qos_dscp_marking_rule,
                       method_args=['rule_id', policy],
                       method_kwargs={'foo': 'bar'},
@@ -604,7 +614,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_minimum_bandwidth_rule_find(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._find',
+        self._verify2('openstack.proxy.Proxy._find',
                       self.proxy.find_qos_minimum_bandwidth_rule,
                       method_args=['rule_id', policy],
                       expected_args=[
@@ -630,7 +640,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
 
     def test_qos_minimum_bandwidth_rule_update(self):
         policy = qos_policy.QoSPolicy.new(id=QOS_POLICY_ID)
-        self._verify2('openstack.proxy2.BaseProxy._update',
+        self._verify2('openstack.proxy.Proxy._update',
                       self.proxy.update_qos_minimum_bandwidth_rule,
                       method_args=['rule_id', policy],
                       method_kwargs={'foo': 'bar'},
@@ -664,6 +674,14 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def test_qos_policy_update(self):
         self.verify_update(self.proxy.update_qos_policy, qos_policy.QoSPolicy)
 
+    def test_qos_rule_type_find(self):
+        self.verify_find(self.proxy.find_qos_rule_type,
+                         qos_rule_type.QoSRuleType)
+
+    def test_qos_rule_type_get(self):
+        self.verify_get(self.proxy.get_qos_rule_type,
+                        qos_rule_type.QoSRuleType)
+
     def test_qos_rule_types(self):
         self.verify_list(self.proxy.qos_rule_types, qos_rule_type.QoSRuleType,
                          paginated=False)
@@ -677,11 +695,24 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def test_quota_get(self):
         self.verify_get(self.proxy.get_quota, quota.Quota)
 
-    @mock.patch.object(proxy_base2.BaseProxy, "_get_resource")
+    @mock.patch.object(proxy_base.Proxy, "_get_resource")
+    def test_quota_get_details(self, mock_get):
+        fake_quota = mock.Mock(project_id='PROJECT')
+        mock_get.return_value = fake_quota
+        self._verify2("openstack.proxy.Proxy._get",
+                      self.proxy.get_quota,
+                      method_args=['QUOTA_ID'],
+                      method_kwargs={'details': True},
+                      expected_args=[quota.QuotaDetails],
+                      expected_kwargs={'project': fake_quota.id,
+                                       'requires_id': False})
+        mock_get.assert_called_once_with(quota.Quota, 'QUOTA_ID')
+
+    @mock.patch.object(proxy_base.Proxy, "_get_resource")
     def test_quota_default_get(self, mock_get):
         fake_quota = mock.Mock(project_id='PROJECT')
         mock_get.return_value = fake_quota
-        self._verify2("openstack.proxy2.BaseProxy._get",
+        self._verify2("openstack.proxy.Proxy._get",
                       self.proxy.get_quota_default,
                       method_args=['QUOTA_ID'],
                       expected_args=[quota.QuotaDefault],
@@ -742,7 +773,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
     def test_router_update(self):
         self.verify_update(self.proxy.update_router, router.Router)
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'add_interface')
     def test_add_interface_to_router_with_port(self, mock_add_interface,
                                                mock_get):
@@ -756,7 +787,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"port_id": "PORT"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'add_interface')
     def test_add_interface_to_router_with_subnet(self, mock_add_interface,
                                                  mock_get):
@@ -770,7 +801,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"subnet_id": "SUBNET"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'remove_interface')
     def test_remove_interface_from_router_with_port(self, mock_remove,
                                                     mock_get):
@@ -784,7 +815,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"port_id": "PORT"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'remove_interface')
     def test_remove_interface_from_router_with_subnet(self, mock_remove,
                                                       mock_get):
@@ -798,7 +829,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"subnet_id": "SUBNET"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'add_gateway')
     def test_add_gateway_to_router(self, mock_add, mock_get):
         x_router = router.Router.new(id="ROUTER_ID")
@@ -811,7 +842,7 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                      expected_kwargs={"foo": "bar"})
         mock_get.assert_called_once_with(router.Router, "FAKE_ROUTER")
 
-    @mock.patch.object(proxy_base2.BaseProxy, '_get_resource')
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
     @mock.patch.object(router.Router, 'remove_gateway')
     def test_remove_gateway_from_router(self, mock_remove, mock_get):
         x_router = router.Router.new(id="ROUTER_ID")
@@ -1064,3 +1095,19 @@ class TestNetworkProxy(test_proxy_base2.TestProxyBase):
                             auto_allocated_topology.ValidateTopology],
                         expected_kwargs={"project": mock.sentinel.project_id,
                                          "requires_id": False})
+
+    def test_set_tags(self):
+        x_network = network.Network.new(id='NETWORK_ID')
+        self._verify('openstack.network.v2.network.Network.set_tags',
+                     self.proxy.set_tags,
+                     method_args=[x_network, ['TAG1', 'TAG2']],
+                     expected_args=[['TAG1', 'TAG2']],
+                     expected_result=mock.sentinel.result_set_tags)
+
+    @mock.patch('openstack.network.v2.network.Network.set_tags')
+    def test_set_tags_resource_without_tag_suport(self, mock_set_tags):
+        no_tag_resource = object()
+        self.assertRaises(exceptions.InvalidRequest,
+                          self.proxy.set_tags,
+                          no_tag_resource, ['TAG1', 'TAG2'])
+        self.assertEqual(0, mock_set_tags.call_count)
